@@ -25,7 +25,7 @@
 
 #include <stdio.h>
 
-main()
+int main()
 {
     int		i, old_i;
 
