@@ -10,11 +10,11 @@ d2 = data.frame(x=c(0,2),y=c(2,2),z=c(4,5))
 g = gstat(NULL,"d1", z~1,~x+y,d1,model=vgm(1, "Exp", 1))
 g = gstat(g,"d2", z~1,~x+y,d2,model=vgm(1, "Exp", 1), merge=c("d1","d2"))
 g = gstat(g, c("d1", "d2"), model = vgm(0.5, "Exp", 1))
-predict.gstat(g, data.frame(x=1,y=1), debug = 32)
+predict(g, data.frame(x=1,y=1), debug = 32)
 
 # Z1 and Z2 share a regression slope:
 g = gstat(NULL,"d1", z~x,~x+y,d1,model=vgm(1, "Exp", 1))
 g = gstat(g,"d2", z~x,~x+y,d2,model=vgm(1, "Exp", 1), 
 	merge=list(c("d1",2,"d2",2)))
 g = gstat(g, c("d1", "d2"), model = vgm(0.5, "Exp", 1))
-predict.gstat(g, data.frame(x=1,y=1), debug = 32)
+predict(g, data.frame(x=1,y=1), debug = 32)
